@@ -1,5 +1,5 @@
 use anyhow::format_err;
-use anyhow::{bail, Result};
+use anyhow::{Result, bail};
 use clap::Parser;
 use maturin::BuildOptions;
 use pretty_assertions::assert_eq;
@@ -108,7 +108,10 @@ pub fn invalid_manylinux_does_not_panic() -> Result<()> {
             .source()
             .ok_or_else(|| format_err!("{}", err))?
             .to_string();
-        assert_eq!(err_string, "manylinux_2_99 compatibility policy is not defined by auditwheel yet, pass `--auditwheel=skip` to proceed anyway");
+        assert_eq!(
+            err_string,
+            "manylinux_2_99 compatibility policy is not defined by auditwheel yet, pass `--auditwheel=skip` to proceed anyway"
+        );
     } else {
         bail!("Should have errored");
     }
@@ -137,7 +140,9 @@ pub fn warn_on_missing_python_source() -> Result<()> {
         );
     }
 
-    assert!(str::from_utf8(&output.stderr)?.contains("Warning: You specified the python source as"));
+    assert!(
+        str::from_utf8(&output.stderr)?.contains("Warning: You specified the python source as")
+    );
     Ok(())
 }
 
