@@ -1,8 +1,9 @@
 //! To speed up the tests, they are tests all collected in a single module
 
+use common::pep517::{target_has_profile, test_pep517};
 use common::{
-    develop, errors, handle_result, integration, other, test_python_implementation,
-    TestInstallBackend,
+    TestInstallBackend, develop, errors, handle_result, integration, other,
+    test_python_implementation,
 };
 use expect_test::expect;
 use maturin::pyproject_toml::SdistGenerator;
@@ -14,8 +15,6 @@ use std::time::Duration;
 use time::macros::datetime;
 use which::which;
 
-use crate::common::{find_subslice, pep517};
-
 mod common;
 
 #[test]
@@ -526,16 +525,18 @@ fn integration_wasm_hello_world() {
         format!("integration-wasm-hello-world-py3-wasm32-wasip1-{python_implementation}");
 
     // Make sure we're actually running wasm
-    assert!(Path::new("test-crates")
-        .join("venvs")
-        .join(venv_name)
-        .join(if cfg!(target_os = "windows") {
-            "Scripts"
-        } else {
-            "bin"
-        })
-        .join("hello-world.wasm")
-        .is_file())
+    assert!(
+        Path::new("test-crates")
+            .join("venvs")
+            .join(venv_name)
+            .join(if cfg!(target_os = "windows") {
+                "Scripts"
+            } else {
+                "bin"
+            })
+            .join("hello-world.wasm")
+            .is_file()
+    )
 }
 
 #[test]
@@ -970,7 +971,7 @@ fn abi3_python_interpreter_args() {
 #[test]
 #[serial(source_date_epoch_env)]
 fn pyo3_source_date_epoch() {
-    env::set_var("SOURCE_DATE_EPOCH", "0");
+    unsafe { env::set_var("SOURCE_DATE_EPOCH", "0") };
     handle_result(other::check_wheel_mtimes(
         "test-crates/pyo3-mixed-include-exclude",
         vec![datetime!(1980-01-01 0:00 UTC)],
@@ -981,7 +982,7 @@ fn pyo3_source_date_epoch() {
 #[test]
 #[serial(source_date_epoch_env)]
 fn sdist_no_source_date_epoch() {
-    env::remove_var("SOURCE_DATE_EPOCH");
+    unsafe { env::remove_var("SOURCE_DATE_EPOCH") };
     handle_result(other::check_sdist_mtimes(
         "test-crates/pyo3-mixed-include-exclude",
         1153704088,
@@ -992,7 +993,7 @@ fn sdist_no_source_date_epoch() {
 #[test]
 #[serial(source_date_epoch_env)]
 fn sdist_source_date_epoch() {
-    env::set_var("SOURCE_DATE_EPOCH", "1");
+    unsafe { env::set_var("SOURCE_DATE_EPOCH", "1") };
     handle_result(other::check_sdist_mtimes(
         "test-crates/pyo3-mixed-include-exclude",
         1,
@@ -1002,32 +1003,28 @@ fn sdist_source_date_epoch() {
 
 #[test]
 fn pep517_default_profile() {
-    let output = handle_result(pep517::test_pep517(
+    let unique_name = "pep517-pyo3-pure";
+    handle_result(test_pep517(
         "test-crates/pyo3-pure",
-        "pep517-pyo3-pure",
+        unique_name,
         false,
         false,
     ));
 
-    assert!(
-        find_subslice(&output.stderr, b"`release` profile [optimized]").is_some(),
-        "Output was: {}",
-        std::str::from_utf8(&output.stderr).unwrap()
-    );
+    assert!(target_has_profile(unique_name, "release"));
+    assert!(!target_has_profile(unique_name, "debug"));
 }
 
 #[test]
 fn pep517_editable_profile() {
-    let output = handle_result(pep517::test_pep517(
+    let unique_name = "pep517-pyo3-pure-editable";
+    handle_result(test_pep517(
         "test-crates/pyo3-pure",
-        "pep517-pyo3-pure-editable",
+        unique_name,
         false,
         true,
     ));
 
-    assert!(
-        find_subslice(&output.stderr, b"`dev` profile [unoptimized + debuginfo]").is_some(),
-        "Output was: {}",
-        std::str::from_utf8(&output.stderr).unwrap()
-    );
+    assert!(!target_has_profile(unique_name, "release"));
+    assert!(target_has_profile(unique_name, "debug"));
 }
